# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 0.x   | :white_check_mark: |

## Reporting a Vulnerability

To report a security issue, please email Michael-Honaker with a description of the issue, the steps you took to create the issue, affected versions, and if known, mitigations for the issue. Our vulnerability management team will acknowledge receiving your email within 3 working days. This project follows a 90 day disclosure timeline.
